/*
 *  
 *  $Id: herramientapaneltags.h 4478 2011-12-13 11:55:00Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

#include <export/iherramientapaneltags.h>
#include <api/icontroladoreventos.h>
#include <api/api.h>

#include <map>

class IconoHerramientaCtrl;
class HerramientaOpcionesGUIBase;

namespace GNC {

	class EXTAPI HerramientaPanelTags : public GNC::GCS::IHerramientaPanelTags, public GNC::GCS::IObservador {

	protected:

	public:
		HerramientaPanelTags();
		~HerramientaPanelTags();

		virtual bool AppendInMenu(wxWindow* pParent, wxMenu* pMenuParent);

		//region "Realizacion de la interfaz IHerramienta"

		// Setup de paneles
		virtual void CrearPaneles( wxPanel* pParent );
		//endregion

		//cuando hacen click en ella...
		bool IsVisible();
		virtual void SolicitarActivacion(const GNC::GCS::TriggerButton& buttonmask);

		virtual void ConectarContratoFalso(bool activar);
		virtual void SetVistaActiva(GNC::GCS::IVista* pVista);
		virtual void ConectarContratos(bool activar);

		virtual void SetVentanaTags(GNC::GCS::IPanelHerramientaTags* pWindow) ;

		virtual void ProcesarEvento(GNC::GCS::Eventos::IEvento *evt);

	protected:
		GNC::GCS::IPanelHerramientaTags*								m_pPanelTags;

	};
}
